cek_hints_path

Function cek_hints_path 

pub fn cek_hints_path() -> BpResult<PathBuf>
Path to the persisted per-chunk CEK hints.

JSON map: { "<chunk_id>": "<hex-encoded 32-byte plaintext hash>" }. The plaintext hash is used to re-derive the per-user CEK at GetFile time. Without this file, files encrypted with a previous daemon session cannot be decrypted after a daemon restart.